@@ -15,6 +15,7 @@ class AgriculturalProduction(BaseModel):
     organicProductionType: int
     variableCosts: float
     landValue: float
+    sellingPrice: float
     
 class AgriculturalProductionDTO(BaseModel):
     id: Optional[int] = None
@@ -26,9 +27,10 @@ class AgriculturalProductionDTO(BaseModel):
     cropProduction: float
     irrigatedArea: float
     cultivatedArea: float
-    organicProductionType: str
+    organicProductionType: int
     variableCosts: float
     landValue: float
+    sellingPrice: float
     
 class LivestockProduction(BaseModel):
     id: Optional[int] = None
@@ -58,6 +60,13 @@ class LivestockProduction(BaseModel):
 class Population(BaseModel):
     id: Optional[int] = None
     description: str
+
+class SyntheticPopulation(BaseModel):
+    id: Optional[int] = None
+    populationId: int
+    yearId: int
+    description: str
+    name: str
     
 class Farm(BaseModel):
     id: Optional[int] = None
@@ -92,10 +101,13 @@ class FADNProductRelation(BaseModel):
 
 class ClosingValue(BaseModel):
     id: Optional[int] = None
-    agriculturalLand: float
+    agriculturalLandArea: float
+    agriculturalLandValue: float
+    plantationsValue: float
     landImprovements: float
-    forestLand: float
-    farmBuildings: float
+    forestLandArea: float
+    forestLandValue: float
+    farmBuildingsValue: float
     machineryAndEquipment: float
     intangibleAssetsTradable: float
     intangibleAssetsNonTradable: float
@@ -118,7 +130,6 @@ class ClosingValue(BaseModel):
     machinery: float
     farmId: int
     yearId: int
-    averageHaPrice: float
     
 class Policy(BaseModel):
     id: Optional[int] = None
@@ -160,18 +171,17 @@ class ValueToLPDTO(BaseModel):
     sE410: float
     aversionRiskFactor: float
     m_0: float
-class CropDataDTO(BaseModel):
 
+class CropDataDTO(BaseModel):
     cropProductiveArea: int
     cropVariableCosts: float
     cropProduction: float
     cropSellingPrice: float
     coupledSubsidy: float
-    uAA: float
+    uaa: float
+
 class ValueFromSPDTO(BaseModel):
-
     farmId: int
-
     totalCurrentAssets: float
     farmNetIncome: float
     farmGrossIncome: float
@@ -211,12 +221,13 @@ class ValueToSPDTO(BaseModel):
     altitude: AltitudeEnum
     currentAssets: float
     decoupledSubsidies: Optional[DecoupledSubsidiesDTO] = None
-    crops: dict[str, CropDataDTO]
+    crops: dict[str,CropDataDTO]
     livestock: Optional[LivestockDTO] = None
 
 class DataToSPDTO(BaseModel):
     values: List[ValueToSPDTO]
     arableProductGroupsNames: List[str]
+    coupledSubsidiesProductGroupsDict: dict[str,str]
 
 class IntermediateValueFromLP(BaseModel):
     farmId: int
@@ -245,6 +256,7 @@ class AgroManagementDecisions(BaseModel):
 class AgroManagementDecisionFromLP(BaseModel):
     agroManagementDecisions: List[AgroManagementDecisions]
     landTransactions: List[LandTransaction]
+    errorList: List[int]
 
 class DataToLPDTO(BaseModel):
     values: List[ValueToLPDTO]
